Test selectWindow
open | ../tests/html/test_select_window.html |
click | popupPage |
waitForPopUp | myPopupWindow | 5000
selectWindow | myPopupWindow |
verifyLocation | */tests/html/test_select_window_popup.html |
verifyTitle | Select Window Popup |
verifyAllWindowNames | *,* |
verifyAllWindowNames | regexp:myPopupWindow |
close |  |
selectWindow | null |
verifyLocation | */tests/html/test_select_window.html |
click | popupPage |
waitForPopUp | myPopupWindow | 5000
selectWindow | myPopupWindow |
verifyLocation | */tests/html/test_select_window_popup.html |
close |  |
selectWindow | null |

Select an anonymous window (one that isn't assigned to a variable)

click | popupAnonymous |
waitForPopUp | anonymouspopup | 5000
selectWindow | anonymouspopup |
verifyLocation | */tests/html/test_select_window_popup.html |
click | closePage |
selectWindow | null |

Try onclick close handler

click | popupAnonymous |
waitForPopUp | anonymouspopup | 5000
selectWindow | anonymouspopup |
verifyLocation | */tests/html/test_select_window_popup.html |
click | closePage2 |

Leave the test in a selected window - the next test should begin in the main window